---
description: Generate and review your platform access tokens.
sidebar:
  order: 11
title: roboto tokens
---
```bash
roboto tokens [-h] {create,delete,list,show} ...
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |

## roboto tokens create

Creates a temporary access token.

```bash
roboto tokens create [-h] --name NAME [--description DESCRIPTION]
                     [--expiry-days {30,60,90}]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--name <name>` Required | A human readable name for this token. |
| `--description <description>` | An optional description for this token. |
| `--expiry-days {30,60,90}` | The number of days this token will be valid for. Default: `30`. |

## roboto tokens delete

Deletes a token by unique token_id.

```bash
roboto tokens delete [-h] --id ID
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--id <id>` Required | The token_id for a token to delete. |

## roboto tokens list

Creates a temporary access token.

```bash
roboto tokens list [-h]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |

## roboto tokens show

Gets a token by unique token_id.

```bash
roboto tokens show [-h] --id ID
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--id <id>` Required | The token_id for a token to look up. |
